import { IUtxoGetTransactionRes, IUtxoTransactionAdditionalData, IUtxoVinTransaction, IUtxoVinVoutsMapper } from "../../types";
import { BalanceDecreasingProps, BalanceDecreasingSummaryResponse, PaymentSummaryProps, PaymentSummaryResponse, TransactionGetterFunction } from "../TransactionBase";
import { UtxoTransaction } from "./UtxoTransaction";
export declare class DogeTransaction extends UtxoTransaction<DogeTransaction> {
    constructor(data: IUtxoGetTransactionRes, additionalData?: IUtxoTransactionAdditionalData);
    isValidPkscript(index: number): boolean;
    get currencyName(): string;
    paymentSummary({ transactionGetter, inUtxo, outUtxo }: PaymentSummaryProps<DogeTransaction>): Promise<PaymentSummaryResponse>;
    balanceDecreasingSummary({ sourceAddressIndicator, transactionGetter, }: BalanceDecreasingProps<DogeTransaction>): Promise<BalanceDecreasingSummaryResponse>;
    makeFull(transactionGetter: TransactionGetterFunction<DogeTransaction>): Promise<void>;
    /**
     * Asserts whether vinvouts Mapper is full mapper and only has unique and matching indices
     * This mapper is required to make full transactions on DOGE chain
     */
    assertAdditionalData(): void;
    /**
     * Checks that additional data mapper for making full transactions is correctly formatted
     * @returns boolean indicator if the object is correctly formatted
     * This mapper is required to make full transactions on DOGE chain
     */
    isValidAdditionalData(): boolean;
    synchronizeAdditionalData(): void;
    /**
     *
     * @param vinIndex vin index
     * @returns vin on vin index
     */
    extractVinAt(vinIndex: number): IUtxoVinTransaction;
    /**
     * Gets the vout corresponding to vin in the given vin index. If the vout is not fetched, the
     * input transaction is read and the corresponding vout is obtained
     * @param vinIndex vin index
     * @param client mcc client for fetching input the transactions
     * @returns input vout of the relevant utxo of the input transaction on the vin on the index `vinIndex`
     */
    private extractVinVoutAt;
    /**
     * Gets the vout corresponding to vin in the given vin index. If it is not stored in the additionalData,
     * it's fetched and updated using the client.
     * @param vinIndex vin index
     * @param client mcc client to fetch transaction data
     * @returns input vout of the relevant utxo of the input transaction on the vin on the index `vinIndex`
     */
    vinVoutAt(vinIndex: number, transactionGetter?: TransactionGetterFunction<DogeTransaction>): Promise<IUtxoVinVoutsMapper>;
    /**
     * Checks if the input on index `vinIndex` is fetched.
     * @param vinIndex vin index
     * @returns true if input on the index `vinIndex` is already fetched.
     */
    isSyncedVinIndex(vinIndex: number): boolean;
    /**
     * Fetches all the vin data from input transactions and makes the payment full_payment.
     * @param client mcc client to use for fetching input data
     */
    makeFullPayment(transactionGetter: TransactionGetterFunction<DogeTransaction>): Promise<void>;
    /**
     * Doge has additional brackets around addresses in out tx
     * @param vout
     * @returns
     */
    private processOutput;
}
//# sourceMappingURL=DogeTransaction.d.ts.map