"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const src_1 = require("../../src");
const testUtils_1 = require("../testUtils");
const DogeMccConnection = {
    url: process.env.DOGE_URL || "",
    username: process.env.DOGE_USERNAME || "",
    password: process.env.DOGE_PASSWORD || "",
    apiTokenKey: process.env.FLARE_API_PORTAL_KEY || "",
};
describe(`Transaction Doge test ,(${(0, testUtils_1.getTestFile)(__filename)})`, function () {
    let MccClient;
    // CONSTANTS
    const txid = "a4d9dbd0047cc48526586fc6d64d4404ba594f5e152e268a48d0abbd786782bc";
    const expected_add = [
        {
            index: 0,
            value: 3967436.83298823,
            address: "D9gTzd79xNDLWfA1BvU3B231ykPvcYy96P",
        },
        {
            index: 1,
            value: 353.657103,
            address: "D9gTzd79xNDLWfA1BvU3B231ykPvcYy96P",
        },
        {
            index: 2,
            value: 1.00000001,
            address: "D9gTzd79xNDLWfA1BvU3B231ykPvcYy96P",
        },
        {
            index: 3,
            value: 556.75685312,
            address: "D9gTzd79xNDLWfA1BvU3B231ykPvcYy96P",
        },
    ];
    before(async function () {
        MccClient = new src_1.MCC.DOGE(DogeMccConnection);
    });
    it("Should update transaction type when making full ", async function () {
        const transaction = await MccClient.getTransaction(txid);
        (0, chai_1.expect)(transaction.type).to.eq("partial_payment");
        const getter = (a) => MccClient.getTransaction(a);
        await transaction.makeFull(getter);
        (0, chai_1.expect)(transaction.type).to.eq("full_payment");
    });
    it("Should check additional data ", async function () {
        var _a, _b;
        const transaction = await MccClient.getTransaction(txid);
        (0, chai_1.expect)(transaction.type).to.eq("partial_payment");
        await transaction.makeFull((a) => MccClient.getTransaction(a));
        (0, chai_1.expect)(transaction.type).to.eq("full_payment");
        const addData = transaction._additionalData.vinouts;
        let indexCounter = 0;
        for (const prevout of addData) {
            // console.log(prevout);
            (0, chai_1.expect)(prevout.index).to.eq(indexCounter);
            const addresses = prevout.vinvout ? (_a = prevout.vinvout) === null || _a === void 0 ? void 0 : _a.scriptPubKey.addresses : ["null"];
            const address = addresses ? (addresses.length >= 1 ? addresses[0] : "null") : "null";
            (0, chai_1.expect)(address).to.eq(expected_add[indexCounter].address);
            (0, chai_1.expect)((_b = prevout.vinvout) === null || _b === void 0 ? void 0 : _b.value).to.eq(expected_add[indexCounter].value);
            indexCounter += 1;
        }
    });
    describe("On Full transaction", async function () {
        let transaction;
        before(async function () {
            transaction = await MccClient.getTransaction(txid);
            const getter = (a) => MccClient.getTransaction(a);
            await transaction.makeFull(getter);
        });
        it("Should check payment summary inUtxo: 0 ; outUtxo: 0 ", async function () {
            const paymentSummary = await transaction.paymentSummary({
                inUtxo: 0,
                outUtxo: 0,
            });
            // console.dir(paymentSummary);
            (0, chai_1.expect)(paymentSummary.status).to.eq("success");
            if (paymentSummary.response) {
                (0, chai_1.expect)(paymentSummary.response.sourceAddress).to.eq("D9gTzd79xNDLWfA1BvU3B231ykPvcYy96P");
                (0, chai_1.expect)(paymentSummary.response.spentAmount.toString(10)).to.eq("54809811860");
                (0, chai_1.expect)(paymentSummary.response.receivedAmount.toString(10)).to.eq("54272811860");
            }
            else {
                (0, chai_1.expect)(false).to.be.true;
            }
        });
        it("Should check payment summary inUtxo: 0 ; outUtxo: 1 ", async function () {
            const paymentSummary = await transaction.paymentSummary({
                inUtxo: 0,
                outUtxo: 1,
            });
            // console.dir(paymentSummary);
            (0, chai_1.expect)(paymentSummary.status).to.eq("success");
            if (paymentSummary.response) {
                (0, chai_1.expect)(paymentSummary.response.sourceAddress).to.eq("D9gTzd79xNDLWfA1BvU3B231ykPvcYy96P");
                (0, chai_1.expect)(paymentSummary.response.spentAmount.toString(10)).to.eq("54809811860");
                (0, chai_1.expect)(paymentSummary.response.receivedAmount.toString(10)).to.eq("-54809811860");
            }
            else {
                (0, chai_1.expect)(false).to.be.true;
            }
        });
        it("Should check payment summary inUtxo: 0 ; outUtxo: 2 ", async function () {
            const paymentSummary = await transaction.paymentSummary({
                inUtxo: 0,
                outUtxo: 2,
            });
            (0, chai_1.expect)(paymentSummary.status).to.eq(src_1.PaymentSummaryStatus.NoReceiveAmountAddress);
        });
    });
});
//# sourceMappingURL=fullTransaction.test.js.map