"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const src_1 = require("../../src");
const testUtils_1 = require("../testUtils");
const console_1 = require("console");
const DogeMccConnection = {
    url: process.env.DOGE_URL || "",
    username: process.env.DOGE_USERNAME || "",
    password: process.env.DOGE_PASSWORD || "",
    apiTokenKey: process.env.FLARE_API_PORTAL_KEY || "",
};
describe(`Transaction summaries, ${(0, testUtils_1.getTestFile)(__filename)}`, function () {
    const MccClient = new src_1.MCC.DOGE(DogeMccConnection);
    describe("full attestation", function () {
        let tx;
        const txId = "2a75d84e2dd7538753b2215b124eb9845f4374944e2dd03d96ed7cdbca0bbf85";
        const getter = (a) => MccClient.getTransaction(a);
        before(async function () {
            tx = await MccClient.getTransaction(txId);
            await tx.makeFull(getter);
        });
        it("Should create payment summary", async function () {
            var _a, _b;
            const summary = await tx.paymentSummary({ transactionGetter: getter, inUtxo: 0, outUtxo: 0 });
            (0, chai_1.expect)(summary.status).to.eq(src_1.PaymentSummaryStatus.Success);
            (0, console_1.assert)(summary.response);
            (0, console_1.assert)((_a = summary.response) === null || _a === void 0 ? void 0 : _a.isFull);
            (0, chai_1.expect)((_b = summary.response) === null || _b === void 0 ? void 0 : _b.transactionStatus).to.eq(src_1.TransactionSuccessStatus.SUCCESS);
        });
        it("Should create balance decreasing summary", async function () {
            var _a, _b, _c;
            const summary = await tx.balanceDecreasingSummary({ transactionGetter: getter, sourceAddressIndicator: src_1.ZERO_BYTES_32 });
            (0, chai_1.expect)(summary.status).to.eq(src_1.BalanceDecreasingSummaryStatus.Success);
            (0, console_1.assert)(summary.response);
            (0, console_1.assert)((_a = summary.response) === null || _a === void 0 ? void 0 : _a.isFull);
            (0, chai_1.expect)((_b = summary.response) === null || _b === void 0 ? void 0 : _b.transactionStatus).to.eq(src_1.TransactionSuccessStatus.SUCCESS);
            (0, chai_1.expect)((_c = summary.response) === null || _c === void 0 ? void 0 : _c.spentAmount.toNumber()).to.eq(209645600000);
        });
    });
    describe("partial attestation", function () {
        let tx;
        const txId = "04292a205004589cbb8223bee8d0d1580846e1e8fb35c4db19d77f1dda126ddd";
        const getter = (a) => MccClient.getTransaction(a);
        before(async function () {
            tx = await MccClient.getTransaction(txId);
        });
        it("should be type payment", function () {
            (0, chai_1.expect)(tx.type).to.eq("partial_payment");
        });
        it("Should create payment summary", async function () {
            var _a, _b;
            const summary = await tx.paymentSummary({ transactionGetter: getter, inUtxo: 0, outUtxo: 0 });
            (0, chai_1.expect)(summary.status).to.eq(src_1.PaymentSummaryStatus.Success);
            (0, console_1.assert)(summary.response);
            (0, console_1.assert)((_a = summary.response) === null || _a === void 0 ? void 0 : _a.isFull);
            (0, chai_1.expect)((_b = summary.response) === null || _b === void 0 ? void 0 : _b.transactionStatus).to.eq(src_1.TransactionSuccessStatus.SUCCESS);
        });
        it("Should create balance decreasing summary", async function () {
            var _a, _b;
            console.log(tx._additionalData.vinouts);
            const summary = await tx.balanceDecreasingSummary({ transactionGetter: getter, sourceAddressIndicator: src_1.ZERO_BYTES_32 });
            console.log(tx._additionalData.vinouts[0]);
            (0, chai_1.expect)(summary.status).to.eq(src_1.BalanceDecreasingSummaryStatus.Success);
            (0, console_1.assert)(summary.response);
            //expect(summary.response?.isFull, "full").to.be.false;
            (0, chai_1.expect)((_a = summary.response) === null || _a === void 0 ? void 0 : _a.transactionStatus).to.eq(src_1.TransactionSuccessStatus.SUCCESS);
            (0, chai_1.expect)((_b = summary.response) === null || _b === void 0 ? void 0 : _b.spentAmount.toNumber()).to.eq(476276000000);
        });
    });
});
//# sourceMappingURL=summary.test.js.map